==> psi4_1.1.orig.tar.gz: psi4-1.1/psi4/src/psi4/libpsio/tocdel.cc <==
/*
 * @BEGIN LICENSE
 *
 * Psi4: an open-source quantum chemistry software package
 *
 * Copyright (c) 2007-2017 The Psi4 Developers.
 *
 * The copyrights for code used from other parties are included in
 * the corresponding files.
 *
 * This file is part of Psi4.
 *
 * Psi4 is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * Psi4 is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along
 * with Psi4; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * @END LICENSE
 */

/*!
 \file
 \ingroup PSIO
 */

#include <cstdio>
#include <unistd.h>
#include <cstdlib>
 #include "psi4/pragma.h"
 PRAGMA_WARNING_PUSH
 PRAGMA_WARNING_IGNORE_DEPRECATED_DECLARATIONS
 #include <memory>
 PRAGMA_WARNING_POP
#include "psi4/libpsi4util/exception.h"
#include "psi4/libpsio/psio.h"
#include "psi4/libpsio/psio.hpp"

namespace psi {

bool PSIO::tocdel(unsigned int unit, const char *key) {
  psio_tocentry *this_entry = tocscan(unit, key);

  if (this_entry == NULL) return false;

  psio_tocentry *last_entry = this_entry->last;
  psio_tocentry *next_entry = this_entry->next;

  if(next_entry == NULL) last_entry->next = NULL;
  else {
    last_entry->next = next_entry;
    next_entry->last = last_entry;
  }

  free(this_entry);
  psio_ud *this_unit = &(psio_unit[unit]);
  this_unit->toclen--;

  return true;
}

bool psio_tocdel(unsigned int unit, const char *key) {
  return _default_psio_lib_->tocdel(unit,key);
}

}

==> psi4_1.2.1.orig.tar.gz: psi4-1.2.1/psi4/src/psi4/libpsio/tocdel.cc <==
/*
 * @BEGIN LICENSE
 *
 * Psi4: an open-source quantum chemistry software package
 *
 * Copyright (c) 2007-2018 The Psi4 Developers.
 *
 * The copyrights for code used from other parties are included in
 * the corresponding files.
 *
 * This file is part of Psi4.
 *
 * Psi4 is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * Psi4 is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along
 * with Psi4; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * @END LICENSE
 */

/*!
 \file
 \ingroup PSIO
 */

#include <cstdio>
#include <unistd.h>
#include <cstdlib>
 #include "psi4/pragma.h"
 PRAGMA_WARNING_PUSH
 PRAGMA_WARNING_IGNORE_DEPRECATED_DECLARATIONS
 #include <memory>
 PRAGMA_WARNING_POP
#include "psi4/libpsi4util/exception.h"
#include "psi4/libpsio/psio.h"
#include "psi4/libpsio/psio.hpp"

namespace psi {

bool PSIO::tocdel(size_t unit, const char *key) {
  psio_tocentry *this_entry = tocscan(unit, key);

  if (this_entry == nullptr) return false;

  psio_tocentry *last_entry = this_entry->last;
  psio_tocentry *next_entry = this_entry->next;

  if(next_entry == nullptr) last_entry->next = nullptr;
  else {
    last_entry->next = next_entry;
    next_entry->last = last_entry;
  }

  free(this_entry);
  psio_ud *this_unit = &(psio_unit[unit]);
  this_unit->toclen--;

  return true;
}

bool psio_tocdel(size_t unit, const char *key) {
  return _default_psio_lib_->tocdel(unit,key);
}

}
